@@ -683,7 +683,7 @@ struct bt_ctf_field_path *pathstr_to_field_path(const char *pathstr,
 		GString *field_path_pretty =
 			bt_ctf_field_path_string(field_path);
 		const char *field_path_pretty_str =
-			field_path_pretty ? field_path_pretty->str : NULL;
+			field_path_pretty ? field_path_pretty->str : "(null)";
 
 		BT_LOGT("Found field path: path=\"%s\", field-path=\"%s\"",
 			pathstr, field_path_pretty_str);
@@ -806,9 +806,9 @@ int get_field_paths_lca_index(struct bt_ctf_field_path *field_path1,
 		GString *field_path2_pretty =
 			bt_ctf_field_path_string(field_path2);
 		const char *field_path1_pretty_str =
-			field_path1_pretty ? field_path1_pretty->str : NULL;
+			field_path1_pretty ? field_path1_pretty->str : "(null)";
 		const char *field_path2_pretty_str =
-			field_path2_pretty ? field_path2_pretty->str : NULL;
+			field_path2_pretty ? field_path2_pretty->str : "(null)";
 
 		BT_LOGT("Finding lowest common ancestor (LCA) between two field paths: "
 			"field-path-1=\"%s\", field-path-2=\"%s\"",
